@@ -107,24 +107,24 @@ func TestHasSideEffects(t *testing.T) {
 		has bool
 	}{
 		{"1", false},
-		{"a", false},
+		{"a", true},
 		{"a++", true},
 		{"a--", true},
 		{"++a", true},
 		{"--a", true},
 		{"delete a", true},
-		{"!a", false},
+		{"!0", false},
 		{"a=5", true},
 		{"a+=5", true},
 		{"a+5", false},
 		{"a()", true},
-		{"a.b", false},
+		{"a.b", true},
 		{"a.b()", true},
 		{"a().b", true},
-		{"a[b]", false},
+		{"a[b]", true},
 		{"a[b()]", true},
 		{"a()[b]", true},
-		{"a?.b", false},
+		{"a?.b", true},
 		{"a()?.b", true},
 		{"a?.b()", true},
 		{"new a", true},
